#[repr(C)]pub struct CreateAuctionArgs {
pub winners: WinnerLimit,
pub end_auction_at: Option<UnixTimestamp>,
pub end_auction_gap: Option<UnixTimestamp>,
pub token_mint: Pubkey,
pub authority: Pubkey,
pub resource: Pubkey,
pub price_floor: PriceFloor,
pub tick_size: Option<u64>,
pub gap_tick_size_percentage: Option<u8>,
}Fields
winners: WinnerLimitHow many winners are allowed for this auction. See AuctionData.
end_auction_at: Option<UnixTimestamp>End time is the cut-off point that the auction is forced to end by. See AuctionData.
end_auction_gap: Option<UnixTimestamp>Gap time is how much time after the previous bid where the auction ends. See AuctionData.
token_mint: PubkeyToken mint for the SPL token used for bidding.
Authority
resource: PubkeyThe resource being auctioned. See AuctionData.
price_floor: PriceFloorSet a price floor.
tick_size: Option<u64>Add a tick size increment
gap_tick_size_percentage: Option<u8>Add a minimum percentage increase each bid must meet.