#[repr(C)]pub enum PriceFloor {
None([u8; 32]),
MinimumPrice([u64; 4]),
BlindedPrice(Hash),
}Expand description
Structure with pricing floor data.
Variants
None([u8; 32])
Due to borsh on the front end disallowing different arguments in enums, we have to make sure data is same size across all three No price floor, any bid is valid.
MinimumPrice([u64; 4])
Explicit minimum price, any bid below this is rejected.
BlindedPrice(Hash)
Hidden minimum price, revealed at the end of the auction.