#[repr(C)]pub struct BidderMetadata {
pub bidder_pubkey: Pubkey,
pub auction_pubkey: Pubkey,
pub last_bid: u64,
pub last_bid_timestamp: UnixTimestamp,
pub cancelled: bool,
}Expand description
Models a set of metadata for a bidder, meant to be stored in a PDA. This allows looking up information about a bidder regardless of if they have won, lost or cancelled.
Fields
bidder_pubkey: Pubkeyauction_pubkey: Pubkeylast_bid: u64last_bid_timestamp: UnixTimestampcancelled: boolImplementations
Sourceimpl BidderMetadata
impl BidderMetadata
pub fn from_account_info( a: &AccountInfo<'_>, ) -> Result<BidderMetadata, ProgramError>